import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:okane/database/database.dart';
import 'package:okane/ui/pages/loans/add_loan_change.dart';
import 'package:okane/ui/state/core.dart';
import 'package:okane/ui/utils.dart';
import 'package:okane/ui/widgets/image_wrapper.dart';

class LoanDetailsPage extends StatelessWidget {
  const LoanDetailsPage({super.key});

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        BlocBuilder<CoreCubit, CoreState>(
          builder: (context, state) {
            if (state.activeLoan == null) {
              return Text("No loan selected");
            }

            final loans = state.activeLoan!.changes.toList();
            final loanSum = loans
                .map((c) => c.amount)
                .reduce((acc, val) => acc + val);
            return CustomScrollView(
              slivers: [
                SliverToBoxAdapter(
                  child: Row(
                    children: [
                      ImageWrapper(
                        title: state.activeLoan!.beneficiary.value!.name,
                        path: state.activeLoan!.beneficiary.value!.imagePath,
                      ),
                      Text(state.activeLoan!.beneficiary.value!.name),
                    ],
                  ),
                ),

                SliverToBoxAdapter(
                  child: Text("Total: ${formatCurrency(loanSum)}"),
                ),

                SliverToBoxAdapter(
                  child: Row(
                    children: [
                      Text("Loan Transactions"),

                      IconButton(
                        onPressed: () {
                          showDialogOrModal(
                            context: context,
                            builder:
                                (_) => AddLoanChangePopup(
                                  loan: state.activeLoan!,
                                  onDone: () {
                                    Navigator.of(context).pop();
                                  },
                                ),
                          );
                        },
                        icon: Icon(Icons.add),
                      ),
                    ],
                  ),
                ),

                SliverList.builder(
                  itemCount: loans.length,
                  itemBuilder: (context, index) {
                    final item = loans[index];

                    return ListTile(
                      leading:
                          item.amount > 0
                              ? Icon(Icons.add, color: Colors.green)
                              : Icon(Icons.remove, color: Colors.red),
                      title: Text(formatCurrency(item.amount)),
                      trailing: IconButton(
                        icon: Icon(Icons.delete, color: Colors.red),
                        onPressed: () async {
                          state.activeLoan!.changes.remove(item);
                          await deleteLoanChange(item);
                          await upsertLoan(state.activeLoan!);
                        },
                      ),
                    );
                  },
                ),
              ],
            );
          },
        ),
      ],
    );
  }
}
